@@ -1,7 +1,7 @@
 package Dancer::Logger::Abstract;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Abstract logging engine for Dancer
-$Dancer::Logger::Abstract::VERSION = '1.3139'; # TRIAL
+$Dancer::Logger::Abstract::VERSION = '1.3141'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -63,9 +63,8 @@ sub format_message {
     my ($self, $level, $message) = @_;
     chomp $message;
 
-    if (!Encode::is_utf8($message) && setting('charset')) {
-        $message = Encode::encode(setting('charset'), $message);
-    }
+    $message = Encode::encode(setting('charset'), $message)
+        if setting('charset');
 
     $level = 'warn' if $level eq 'warning';
     $level = sprintf('%5s', $level);
@@ -157,7 +156,7 @@ Dancer::Logger::Abstract - Abstract logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3139
+version 1.3141
 
 =head1 SYNOPSIS
 
